==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/mail/SendMailMessageFailedException.hpp <==
#ifndef _COM_SUN_STAR_MAIL_SENDMAILMESSAGEFAILEDEXCEPTION_HPP_
#define _COM_SUN_STAR_MAIL_SENDMAILMESSAGEFAILEDEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_MAIL_SENDMAILMESSAGEFAILEDEXCEPTION_HDL_
#include "com/sun/star/mail/SendMailMessageFailedException.hdl"
#endif

#ifndef _COM_SUN_STAR_MAIL_MAILEXCEPTION_HPP_
#include "com/sun/star/mail/MailException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif

namespace com { namespace sun { namespace star { namespace mail {

inline SendMailMessageFailedException::SendMailMessageFailedException() SAL_THROW( () )
    : ::com::sun::star::mail::MailException()
    , InvalidAddresses()
    , ValidSentAddresses()
    , ValidUnsentAddresses()
{ }

inline SendMailMessageFailedException::SendMailMessageFailedException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::uno::Sequence< ::rtl::OUString >& InvalidAddresses_, const ::com::sun::star::uno::Sequence< ::rtl::OUString >& ValidSentAddresses_, const ::com::sun::star::uno::Sequence< ::rtl::OUString >& ValidUnsentAddresses_) SAL_THROW( () )
    : ::com::sun::star::mail::MailException(Message_, Context_)
    , InvalidAddresses(InvalidAddresses_)
    , ValidSentAddresses(ValidSentAddresses_)
    , ValidUnsentAddresses(ValidUnsentAddresses_)
{ }

SendMailMessageFailedException::SendMailMessageFailedException(SendMailMessageFailedException const & the_other): ::com::sun::star::mail::MailException(the_other), InvalidAddresses(the_other.InvalidAddresses), ValidSentAddresses(the_other.ValidSentAddresses), ValidUnsentAddresses(the_other.ValidUnsentAddresses) {}

SendMailMessageFailedException::~SendMailMessageFailedException() {}

SendMailMessageFailedException & SendMailMessageFailedException::operator =(SendMailMessageFailedException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::mail::MailException::operator =(the_other);
    InvalidAddresses = the_other.InvalidAddresses;
    ValidSentAddresses = the_other.ValidSentAddresses;
    ValidUnsentAddresses = the_other.ValidUnsentAddresses;
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::mail::SendMailMessageFailedException* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.mail.SendMailMessageFailedException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_MAIL_SENDMAILMESSAGEFAILEDEXCEPTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/mail/SendMailMessageFailedException.hpp <==
#ifndef _COM_SUN_STAR_MAIL_SENDMAILMESSAGEFAILEDEXCEPTION_HPP_
#define _COM_SUN_STAR_MAIL_SENDMAILMESSAGEFAILEDEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_MAIL_SENDMAILMESSAGEFAILEDEXCEPTION_HDL_
#include "com/sun/star/mail/SendMailMessageFailedException.hdl"
#endif

#ifndef _COM_SUN_STAR_MAIL_MAILEXCEPTION_HPP_
#include "com/sun/star/mail/MailException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif

namespace com { namespace sun { namespace star { namespace mail {

inline SendMailMessageFailedException::SendMailMessageFailedException() SAL_THROW( () )
    : ::com::sun::star::mail::MailException()
    , InvalidAddresses()
    , ValidSentAddresses()
    , ValidUnsentAddresses()
{ }

inline SendMailMessageFailedException::SendMailMessageFailedException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::uno::Sequence< ::rtl::OUString >& InvalidAddresses_, const ::com::sun::star::uno::Sequence< ::rtl::OUString >& ValidSentAddresses_, const ::com::sun::star::uno::Sequence< ::rtl::OUString >& ValidUnsentAddresses_) SAL_THROW( () )
    : ::com::sun::star::mail::MailException(Message_, Context_)
    , InvalidAddresses(InvalidAddresses_)
    , ValidSentAddresses(ValidSentAddresses_)
    , ValidUnsentAddresses(ValidUnsentAddresses_)
{ }

SendMailMessageFailedException::SendMailMessageFailedException(SendMailMessageFailedException const & the_other): ::com::sun::star::mail::MailException(the_other), InvalidAddresses(the_other.InvalidAddresses), ValidSentAddresses(the_other.ValidSentAddresses), ValidUnsentAddresses(the_other.ValidUnsentAddresses) {}

SendMailMessageFailedException::~SendMailMessageFailedException() {}

SendMailMessageFailedException & SendMailMessageFailedException::operator =(SendMailMessageFailedException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::mail::MailException::operator =(the_other);
    InvalidAddresses = the_other.InvalidAddresses;
    ValidSentAddresses = the_other.ValidSentAddresses;
    ValidUnsentAddresses = the_other.ValidUnsentAddresses;
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace mail {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::mail::SendMailMessageFailedException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.mail.SendMailMessageFailedException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::mail::SendMailMessageFailedException const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::mail::SendMailMessageFailedException >::get();
}

#endif // _COM_SUN_STAR_MAIL_SENDMAILMESSAGEFAILEDEXCEPTION_HPP_
